<template>
  <el-card style="border-radius: 0" :body-style="{ padding: '1rem 2rem' }" v-loading="loading">
    <template #header>
      <div style="font-weight: bold; font-size: 1.2rem">维保统计</div>
    </template>
    <div ref="chartDom" style="height: 25rem; width: 100%"></div>
  </el-card>
</template>

<script setup>
import { ref, onMounted, onUnmounted, nextTick } from "vue";
// 引入echarts
import * as echarts from "echarts";
import { GetMaintenanceDistApi } from "../../api/dashboard";
import { ElLoading } from 'element-plus'
const loading=ref(true)
// 创建一个响应式引用来保存DOM元素
const chartDom = ref(null);
let chartInstance = null;

const xData = ref([])
const yData = ref([])


// 初始化ECharts实例并设置配置项（这里以折线图为例，但可灵活替换）
onMounted(async () => {
  await GetMaintenanceDistApi().then(res => {
    xData.value = res.data.map(i=>i.year)
    yData.value = res.data.map(i=>i.sumCount)
  })


  await nextTick(); // 确保DOM已经渲染完成
  chartInstance = echarts.init(chartDom.value);

  const option = {
    // backgroundColor: "#0f375f",
    grid: {
      top: "20%",
      bottom: "10%", //也可设置left和right设置距离来控制图表的大小
      left: "7%",
      right: 0,
    },
    tooltip: {
      trigger: "axis",
      axisPointer: {
        type: "shadow",
        label: {
          show: true,
        },
      },
    },
    legend: {
      data: ["维保数量"],
      top: "0%",
      right: "0%",
      textStyle: {
        color: "#000",
      },
    },
    xAxis: {
      data: xData.value,
      axisLine: {
        show: true, //隐藏X轴轴线
        lineStyle: {
          color: "#000",
        },
      },
      axisTick: {
        show: true, //隐藏X轴刻度
      },
      axisLabel: {
        show: true,
        textStyle: {
          color: "#000", //X轴文字颜色
        },
      },
    },
    yAxis: [
      {
        type: "value",
        minInterval:1,
        name: "件",
        nameTextStyle: {
          color: "#000",
        },
        splitLine: {
          show: false,
        },
        axisTick: {
          show: true,
        },
        axisLine: {
          show: true,
          lineStyle: {
            color: "#666",
          },
        },
        axisLabel: {
          show: true,
          textStyle: {
            color: "#666",
          },
        },
        splitLine: {
          // 网格线
          show: true,
          lineStyle: { //分割线
            color: "#eee",
            width: 1,
            type: "dashed" //dotted：虚线 solid:实线
          }
        },
      },
      {
        type: "value",
        gridIndex: 0,
        min: 50,
        max: 100,
        splitNumber: 8,
        splitLine: {
          show: false,
        },
        axisLine: {
          show: false,
        },
        axisTick: {
          show: false,
        },
        axisLabel: {
          show: false,
        },
        splitArea: {
          show: true,
          areaStyle: {
            color: ["rgba(250,250,250,0.0)", "rgba(250,250,250,0.05)"],
          },
        },
      },
    ],
    series: [
      // {
      //   name: "维保数量",
      //   type: "line",
      //   barWidth: 15,
      //   itemStyle: {
      //     normal: {
      //       color: "#ff3333"
      //     },
      //   },
      //   data: yData.value,
      // },
      {
        name: "维保数量",
        type: "bar",
        barWidth: 15,
        itemStyle: {
          normal: {
            color: "#0099ff"
          },
        },
        data: yData.value,
      },
    ],
  };
  chartInstance.setOption(option);
  nextTick(() => {
    loading.value = false;
  })
});

// 销毁ECharts实例
onUnmounted(() => {
  if (chartInstance != null && chartInstance.dispose) {
    chartInstance.dispose();
  }
});

//窗口大小变化重绘echart
window.onresize = function () {
  if (chartInstance != null && chartInstance.resize) {
    chartInstance.resize();
  }
};
</script>

<style></style>